Name:          nom-tam-fits
Version:       1.15.2
Release:       %mkrel 7
Group:         Development/Java
Summary:       Java library for reading and writing FITS files
License:       Public Domain
URL:           https://nom-tam-fits.github.io/nom-tam-fits/
Source0:       https://github.com/nom-tam-fits/nom-tam-fits/archive/%{name}-%{version}.tar.gz
Patch0:        0001-Skip-tests-if-we-cannot-download-images.patch

BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.commons:commons-compress)
BuildRequires: mvn(org.codehaus.mojo:exec-maven-plugin)

# retired in Fedora:
# BuildRequires: mvn(org.openjdk.jmh:jmh-core)
# BuildRequires: mvn(org.openjdk.jmh:jmh-generator-annprocess)

BuildArch:     noarch
#ExclusiveArch:  %%{java_arches} noarch

%description
FITS (Flexible Image Transport System) is the standard data format in
astronomy used for the transport, analysis, and archival storage of
scientific data sets.

This library provides efficient I/O for FITS images and binary tables.
All basic FITS formats and GZIP compressed files are supported.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%autosetup -n %{name}-%{name}-%{version} -p1
rm -r src/main/fpack

# remove unnecessary dependency on parent POM
%pom_remove_parent

# com.github.stephenc.wagon:wagon-gitsite:0.5
%pom_xpath_remove pom:build/pom:extensions
# Disable classpath in MANIFEST file
%pom_xpath_set pom:addClasspath false

# Unwanted tasks
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :maven-assembly-plugin
%pom_remove_plugin :maven-deploy-plugin
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin :maven-source-plugin

# Not available plugins
%pom_remove_plugin com.googlecode.maven-java-formatter-plugin:maven-java-formatter-plugin
%pom_remove_plugin org.codehaus.mojo:findbugs-maven-plugin
%pom_remove_plugin org.codehaus.mojo:license-maven-plugin
%pom_remove_plugin org.eluder.coveralls:coveralls-maven-plugin
%pom_remove_plugin org.tinyjee.dim:doxia-include-macro
%pom_remove_plugin :maven-pdf-plugin
# Use doxia-include-macro
%pom_remove_plugin :maven-site-plugin

# Not available test dep com.nanohttpd:nanohttpd-webserver:2.1.1
%pom_remove_dep :nanohttpd-webserver
# rm src/test/java/nom/tam/fits/test/CompressTest.java
# Error occurred during initialization of VM
# Could not reserve enough space for 2097152KB object heap
%pom_xpath_remove pom:argLine
# rm src/test/java/nom/tam/fits/compression/ReadWriteProvidedCompressedImageTest.java
# UnsupportedOperationException: could not get blackbox image from anywhere (use web connection)
# rm src/test/java/nom/tam/fits/test/UserProvidedTest.java

# https://bugzilla.redhat.com/show_bug.cgi?id=1736095
%pom_remove_plugin :maven-checkstyle-plugin

%pom_remove_plugin :maven-compiler-plugin
%pom_add_plugin org.apache.maven.plugins:maven-compiler-plugin  . "
<executions>
  <execution>
    <id>default-compile</id>
    <phase>compile</phase>
    <configuration>
      <source>1.8</source>
      <target>1.8</target>
    </configuration>
    <goals>
      <goal>compile</goal>
    </goals>
  </execution>
  <execution>
    <id>default-testCompile</id>
    <phase>test-compile</phase>
    <configuration>
      <source>1.8</source>
      <target>1.8</target>
      <testExcludes>
        <exclude>**/CompressTest.*</exclude>
        <exclude>**/CompressWithoutDependenciesTest.*</exclude>
        <exclude>**/ReadWriteProvidedCompressedImageTest.*</exclude>
        <exclude>**/UserProvidedTest.*</exclude>
      </testExcludes>
    </configuration>
    <goals>
      <goal>testCompile</goal>
    </goals>
  </execution>
</executions>"

# retired in Fedora
%pom_remove_dep org.openjdk.jmh:
rm src/test/java/nom/tam/manual/intergration/FitsBenchmark.java
rm src/test/java/nom/tam/image/compression/hdu/CompressedTableTest.java

# Retired in Fedora; not required for build
%pom_remove_dep com.google.code.findbugs:annotations
sed -i 's/.*SuppressFBWarnings.*//' $(fgrep -lr SuppressFBWarnings src/main/java)

%mvn_file :%{name} %{name} fits

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc target/NOTE.* README.md
%license src/license/publicdomain/license.txt

%files javadoc -f .mfiles-javadoc
%license src/license/publicdomain/license.txt



%changelog
* Tue Jul 01 2025 umeabot <umeabot> 1.15.2-7.mga10
+ Revision: 2232637
- Mageia 10 Mass Rebuild

* Mon Dec 23 2024 daviddavid <daviddavid> 1.15.2-6.mga10
+ Revision: 2129330
- fix testsuite

* Mon May 27 2024 ns80 <ns80> 1.15.2-5.mga10
+ Revision: 2068261
- rebuild for java 21

* Fri Jan 27 2023 daviddavid <daviddavid> 1.15.2-4.mga9
+ Revision: 1936445
- fix build excluding CompressWithoutDependenciesTest.java test file
- Remove unnecessary findbugs dependency (#1966790)
- Remove unnecessary dependency on parent POM
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Sep 08 2020 daviddavid <daviddavid> 1.15.2-3.mga8
+ Revision: 1623431
- Disable test which requires jmh (#1799807)

* Sat Feb 15 2020 umeabot <umeabot> 1.15.2-2.mga8
+ Revision: 1528345
- Mageia 8 Mass Rebuild

* Mon Aug 19 2019 daviddavid <daviddavid> 1.15.2-1.mga8
+ Revision: 1429933
- Update to latest version 1.15.2

* Thu Sep 20 2018 umeabot <umeabot> 1.15.1-2.mga7
+ Revision: 1281311
- Mageia 7 Mass Rebuild

* Fri May 04 2018 daviddavid <daviddavid> 1.15.1-1.mga7
+ Revision: 1226091
- imported package nom-tam-fits


* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Dec  8 2016 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.15.1-1
- Update to latest version

* Sun Apr 03 2016 gil cattaneo <puntogil@libero.it> 1.14.2-1
- initial rpm
